<?php

declare(strict_types=1);

namespace Drupal\media_icon_deliver\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Media Icon Deliver settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'media_icon_deliver_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['media_icon_deliver.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    // Fetch all media fields of type image, but only on entity type 'media'.
    // Only consider fields starting with 'field_'.
    $fields = \Drupal::service('entity_field.manager')->getFieldMapByFieldType('image');
    $media_fields = array_filter($fields['media'], function ($field_name) {
      return strpos($field_name, 'field_') === 0;
    }, ARRAY_FILTER_USE_KEY);

    $options = [];
    foreach ($media_fields as $field_name => $field) {
      $options[$field_name] = $field_name . ' (' . implode(', ', $field['bundles']) . ')';
    }

    $form['field_name'] = [
      '#type' => 'select',
      '#title' => $this->t('Field name'),
      '#options' => $options,
      '#required' => TRUE,
      '#default_value' => $this->config('media_icon_deliver.settings')->get('field_name'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('media_icon_deliver.settings')
      ->set('field_name', $form_state->getValue('field_name'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
